@@ -2,6 +2,8 @@ from .config import PATH, PDF_REPORT_JOB_FOLDER
 from .security import get_access_token
 from .process_job import process_job
 from .logging import logger
+from croniter import croniter
+from datetime import datetime
 import json
 import shutil
 
@@ -23,16 +25,22 @@ class PDF_report:
         job_detail = json.load(file)
         file.close()
 
+        # Check if selected job is active
+        if not job_detail["active"]:
+            logger.info("Job {} ist not active".format(job))
+            return 0
+
+        # Check selected job timing
+        if not croniter.match(job_detail["schedule"], datetime.now()):
+            return 0
+
         #Copy <your_job>.tex
         if not PDF_REPORT_JOB_FOLDER == None:
             src="{}/{}".format(PDF_REPORT_JOB_FOLDER, job_detail["filename"])
             des="{}latex/{}".format(PATH, job_detail["filename"])
             shutil.copy(src, des)
 
-        # Check if selected job is active
-        if not job_detail["active"]:
-            print("Job {} ist not active".format(job))
-            return 0
+        
 
         # Get access-token via API-Login
         logger.info("Get access token")
