@@ -3,6 +3,7 @@ from celery.utils.log import get_task_logger
 from supersetpdfreport.pdf_report import PDF_report
 from typing import Any
 import logging
+import glob
 
 logger = get_task_logger(__name__)
 logger.setLevel(logging.INFO)
@@ -10,9 +11,13 @@ logger.setLevel(logging.INFO)
 
 @celery_app.task(name="pdf-report")
 def pdf_report(job_name: str, *args: Any, **kwargs: Any) -> None:
+
     logger.info("superset_pdf_report started")
+    joblist = glob.glob('*.json')
 
-    pdf_report_task = PDF_report()
-    pdf_report_task.execute(job_name)
-
+    for job_name in joblist:
+        pdf_report_task = PDF_report()
+        pdf_report_task.execute(job_name)
+    
+    
     logger.info("superset_pdf_report finished")
